3 results for "Light Bulbs" | 1000bulbs.com
Description: America's Largest Online Light Bulb Retailer! Thousands of Halogens, CFLs, Automotive Bulbs, Christmas Lights, LEDs, Rope Lights, and Electrical Supplies.
Keywords: Light bulbs, halogen lightbulbs, rope lights, christmas lights, ballasts, fluorescent bulbs

For expert help, call: 1-800-624-4488

Don't have an account? Signup

#### Login

Email Password Remember Me

Forgot Password?

Product Search

For expert help, call: 1-800-624-4488

Advanced Search Advanced Search
Brand
□ American Light Bulb (1) □ American Lighting (1) □ Antique Light Bulb Co. (56) □ Atlantic Ultraviolet (4) □ Bulbrite (228) □ Craftmade (2) □ Cree (9) □ Diogen (2) □ EYE Lighting (23) □ EiKO (610) □ Energetic Lighting (1) □ Energy Miser (73) □ Feit (1) □ FerroWatt (1) □ GE (444) □ GELCO (8) □ Global Consumer (131) □ Green Creative (32) □ HLS (3) □ Halco (173) □ Halco HaloXen (7) □ Halo (2) □ Havells (2) □ Hikari (70) Hortilux (3) □ Hudson Valley Lighting (1) □ KLS (8) □ Kobi (11) □ LifeBulb (44) □ Litetronics (31) □ Litetronics MicroBrite (12) □ Litetronics Neolite (5) □ Lutron (8) □ MaxLite (31) □ Nora Lighting (6) □ Nuvo Lighting (1) □ Osram (21) □ PLT (837) □ Philips (346) □ Plantmax (1) □ Plusrite (282) □ Promolux (23) □ SLi Lighting (3) □ SYLVANIA (554) □ Satco (423) □ Sunlite (34) □ TCP (287) □ Topstar (1) □ Ushio (315) □ Venture (44) □ ViriBright (3) □ Westinghouse Radiant (7)
Bulb Shape
□ BT37 (2) □ T17 (1)
Base Type
□ Mogul (E39) (3)
Wattage
□ 400-420 (2) □ 1000-1020 (1)

### 3 results for "Light Bulbs"

Sort By
Sort By

- Brand: Hortilux

MH400-HTL

#### 400 Watt - Probe Start - Metal Halide Grow Light - BT37 - Reduced Envelope - Unprotected Arc Tube - 4200K - ANSI M59/E - Mogul Base - Horizontal Burn - MH400/HOR/HTL - Hortilux 53941

- Brand : Hortilux
- Part No. : 53941
- Order Code : M400/HOR/HTL
- Base Type : Mogul (E39)
- Family : Hortilux
- Bulb Shape : BT37
- Case Quantity : 12
- Burn Position : Horizontal +/- 15 Degrees
- ANSI Code : M59/E
- Protected : No
- Life Hours : 20,000
- Wattage : 400.0 Watt
- Color Temperature : 4200 Kelvin
- CRI : 65.0
- Lumens (Initial) : 39000.0

$48.75 ea
An error has occurred
Checkout
Quantity

MH400-HTL

Checkout

MH1000B-HTL

#### 1000 Watt - Probe Start - Metal Halide Grow Light - BT37 - Reduced Envelope - Unprotected Arc Tube - 4200K - ANSI M47/E - Mogul Base - Universal Burn - MH1000B/U/BT37/HTL - Hortilux 53967

- Brand : Hortilux
- Part No. : 53967
- Order Code : M1000B/U/BT37/HTL
- Base Type : Mogul (E39)
- Family : Hortilux
- Bulb Shape : BT37
- Case Quantity : 12
- Burn Position : Universal
- ANSI Code : M47/E
- Protected : No
- Life Hours : 12,000
- Wattage : 1000.0 Watt
- Color Temperature : 4200 Kelvin
- CRI : 65.0
- Lumens (Initial) : 115000.0

$63.00 ea
An error has occurred
Checkout
Quantity

MH1000B-HTL

Checkout

MT400D-HTL

#### 400 Watt - Probe Start - Metal Halide Grow Light - T17 - Tubular Envelope - Unprotected Arc Tube - 6500K - ANSI M59/E - Mogul Base - Horizontal Burn - MT400D/HOR/HTL-BLUE - Hortilux Blue 57816

- Brand : Hortilux
- Part No. : 57816
- Order Code : MT400D/HOR/HTL-BLUE
- Base Type : Mogul (E39)
- Family : Hortilux Blue
- Bulb Shape : T17
- Case Quantity : 12
- Burn Position : Horizontal +/- 15 Degrees
- Warranty : 1 Year
- ANSI Code : M59/E
- Protected : No
- Life Hours : 12,000
- Wattage : 400.0 Watt
- Color Temperature : 6500 Kelvin
- CRI : 90.0
- Lumens (Initial) : 29000.0

$79.12 ea
An error has occurred
Checkout
Quantity

MT400D-HTL

Checkout